Template
========

Static methods to wrap text in ANSI Colours.

Installation
------------

Install by running:

    pip install ansi_colours

Usage
-----

    import AnsiColours as colour from ansi_colours
    # Red text
    colour.red("I'm red")

License
-------

The project is licensed under the MIT license.